@@ -25,6 +25,8 @@
 #'   of the "curves" and "fullsims" argument values. 
 #'
 #' @examples
+#' \dontshow{.old_wd <- setwd(tempdir())}
+#' \donttest{
 #' # load simulated data and fitted model (see ?sim_data and ?jags_logit)
 #' data("jags_logit")
 #' 
@@ -34,10 +36,17 @@
 #'                       xnames = c("X1", "X2"),
 #'                       curves = TRUE,
 #'                       fullsims = FALSE)
+#' }
 #' 
+#' \dontshow{setwd(.old_wd)}
 #' @export
 #' @md
-mcmcRocPrc <- function(object, yname, xnames, curves, fullsims) {
+
+mcmcRocPrc <- function(object, 
+                       yname, 
+                       xnames, 
+                       curves, 
+                       fullsims) {
   
   link_logit  <- any(grepl("logit", object$model$model()))
   link_probit <- any(grepl("probit", object$model$model()))
